@@ -45,7 +45,7 @@ import ppauto
 import ppcommon
 
 copyright = "Copyright (c) 2005-2012 Vitalii Vanovschi. All rights reserved"
-version = "1.6.4"
+version = "1.6.5"
 
 # Reconnect persistent rworkers in seconds.
 RECONNECT_WAIT_TIME = 5
@@ -332,8 +332,9 @@ class Server(object):
         pythondirs = [os.getcwd()] + sys.path
 
         if "PYTHONPATH" in os.environ and os.environ["PYTHONPATH"]:
-            pythondirs += os.environ["PYTHONPATH"].split(os.pathsep)
-        os.environ["PYTHONPATH"] = os.pathsep.join(set(pythondirs))
+            pythondirs = os.environ["PYTHONPATH"].split(os.pathsep) + pythondirs
+        dirset = set()        
+        os.environ["PYTHONPATH"] = os.pathsep.join([dirset.add(x) or x for x in pythondirs if x not in dirset])
 
         atexit.register(self.destroy)
         self.__stats = {"local": _Statistics(0)}
